% Pitch marking with and without laringograph 

clear
close all
clc

path('..\..\voicebox',path)

%% Read data containing WAV and EGG signal (from ARCTIC)
%  (first channel contains sound, second channel contains EGG)
[data fs] = wavread('bdl_arctic_a0013.wav');
x   = resample(data(:,1), 1,2);
egg = resample(data(:,2), 1,2);
fs  = fs/2;
% soundsc(x,fs);

%% Estimate voicing (using earlier approach in ex8p2.m)
%  Needed to eliminate false GCIs in DYPSA)
wlen  = round(30e-3*fs);
wshft = round(1e-3*fs);
nfft  = 1024;

[voiced] = vuv(x,fs,wlen,wshft);

% Resample the voiced detector to match fs
voiced_fs = resample(voiced, length(x), length(voiced));

%% Estimate instants of glottal closure and opening 

% From the speech signal
[gci_x,goi_x] = dypsa(x,fs);

% Remove GCI and GOI from unvoiced segments
for t = length(gci_x):-1:1
  if ~voiced_fs(gci_x(t))
    gci_x(t) = [];
    goi_x(t) = [];
  end
end

% From the EGG signal (signal needs to be reversed; see figure 1 in 
% publication by authors)
[gci_e goi_e] = sigma(-egg,fs,200);

%% Plot estimated GCIs and GOIs
% Normalize signals (for visualization purposes)
x    = (x-mean(x))/std(x);
egg  = (egg-mean(egg))/std(egg);
degg = diff(egg);
degg = (degg)/std(degg);

hold on
plot(x, 'b'); axis tight
plot(egg, 'r'); axis tight
plot(degg, 'g'); axis tight

legend('wav', 'egg', 'd-egg')

plot([gci_x; goi_x], [-1 -1], 'b', 'LineWidth', 2);
plot([gci_e; goi_e], [1 1], 'g', 'LineWidth', 2);

plot([min(gci_e) max(gci_e)], [0 0], 'k-')

save ex8p3